@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  *
  */
 
-#include <string.h>
 #include <stdio.h>
+#include <string.h>
 
 #define G_UDEV_API_IS_SUBJECT_TO_CHANGE
 #ifdef G_UDEV_API_IS_SUBJECT_TO_CHANGE
@@ -29,61 +29,57 @@
 #include "entangle-debug.h"
 #include "entangle-device-manager.h"
 
-#define ENTANGLE_DEVICE_MANAGER_GET_PRIVATE(obj)                        \
-    (G_TYPE_INSTANCE_GET_PRIVATE((obj), ENTANGLE_TYPE_DEVICE_MANAGER, EntangleDeviceManagerPrivate))
+/**
+ * SECTION:entangle-device-manager
+ * @Short_description: a way for monitoring devices on the host
+ * @Title: EntangleDeviceManager
+ *
+ * The #EntangleDeviceManager provides a way to monitor devices on the
+ * host.
+ */
 
-struct _EntangleDeviceManagerPrivate {
+struct _EntangleDeviceManager
+{
+    GObject parent;
     GUdevClient *ctx;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE(EntangleDeviceManager, entangle_device_manager, G_TYPE_OBJECT);
+G_DEFINE_TYPE(EntangleDeviceManager, entangle_device_manager, G_TYPE_OBJECT);
 
-
-static void entangle_device_manager_finalize(GObject *object)
+static void
+entangle_device_manager_finalize(GObject *object)
 {
     EntangleDeviceManager *manager = ENTANGLE_DEVICE_MANAGER(object);
-    EntangleDeviceManagerPrivate *priv = manager->priv;
+
     ENTANGLE_DEBUG("Finalize manager");
 
-    if (priv->ctx)
-        g_object_unref(priv->ctx);
+    if (manager->ctx)
+        g_object_unref(manager->ctx);
 
     G_OBJECT_CLASS(entangle_device_manager_parent_class)->finalize(object);
 }
 
-
-static void entangle_device_manager_class_init(EntangleDeviceManagerClass *klass)
+static void
+entangle_device_manager_class_init(EntangleDeviceManagerClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
     object_class->finalize = entangle_device_manager_finalize;
 
-    g_signal_new("device-added",
-                 G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_FIRST,
-                 0, NULL, NULL,
-                 g_cclosure_marshal_VOID__STRING,
-                 G_TYPE_NONE,
-                 1,
-                 G_TYPE_STRING,
-                 G_TYPE_STRING);
+    g_signal_new("device-added", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_FIRST,
+                 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
+                 G_TYPE_STRING, G_TYPE_STRING);
 
-    g_signal_new("device-removed",
-                 G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_FIRST,
-                 0, NULL, NULL,
-                 g_cclosure_marshal_VOID__STRING,
-                 G_TYPE_NONE,
-                 1,
-                 G_TYPE_STRING,
-                 G_TYPE_STRING);
+    g_signal_new("device-removed", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_FIRST,
+                 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
+                 G_TYPE_STRING, G_TYPE_STRING);
 }
 
-
-static void do_udev_event(GUdevClient *client G_GNUC_UNUSED,
-                          const char *action,
-                          GUdevDevice *dev,
-                          gpointer opaque)
+static void
+do_udev_event(GUdevClient *client G_GNUC_UNUSED,
+              const char *action,
+              GUdevDevice *dev,
+              gpointer opaque)
 {
     EntangleDeviceManager *manager = opaque;
     const gchar *sysfs;
@@ -92,13 +88,11 @@ static void do_udev_event(GUdevClient *client G_GNUC_UNUSED,
     const gchar *serial;
     gchar *port;
 
-    if (strcmp(action, "add") != 0 &&
-        strcmp(action, "remove") != 0)
+    if (strcmp(action, "add") != 0 && strcmp(action, "remove") != 0)
         return;
 
     devtype = g_udev_device_get_devtype(dev);
-    if ((devtype == NULL) ||
-        strcmp(devtype, "usb_device") != 0)
+    if ((devtype == NULL) || strcmp(devtype, "usb_device") != 0)
         return;
 
     sysfs = g_udev_device_get_sysfs_path(dev);
@@ -107,9 +101,7 @@ static void do_udev_event(GUdevClient *client G_GNUC_UNUSED,
     usbdev = g_udev_device_get_property(dev, "DEVNUM");
     serial = g_udev_device_get_property(dev, "ID_SERIAL");
 
-    if (sysfs == NULL ||
-        usbbus == NULL ||
-        usbdev == NULL)
+    if (sysfs == NULL || usbbus == NULL || usbdev == NULL)
         return;
 
     port = g_strdup_printf("usb:%s,%s", usbbus, usbdev);
@@ -124,34 +116,36 @@ static void do_udev_event(GUdevClient *client G_GNUC_UNUSED,
     g_free(port);
 }
 
-
-EntangleDeviceManager *entangle_device_manager_new(void)
+EntangleDeviceManager *
+entangle_device_manager_new(void)
 {
-    return ENTANGLE_DEVICE_MANAGER(g_object_new(ENTANGLE_TYPE_DEVICE_MANAGER, NULL));
+    return ENTANGLE_DEVICE_MANAGER(
+        g_object_new(ENTANGLE_TYPE_DEVICE_MANAGER, NULL));
 }
 
-
-static void entangle_device_manager_init_devices(EntangleDeviceManager *manager)
+static void
+entangle_device_manager_init_devices(EntangleDeviceManager *manager)
 {
-    EntangleDeviceManagerPrivate *priv = manager->priv;
     GList *devs, *tmp;
     const gchar *const subsys[] = {
-        "usb/usb_device", NULL,
+        "usb/usb_device",
+        NULL,
     };
 
     ENTANGLE_DEBUG("Init udev");
 
-    priv->ctx = g_udev_client_new(subsys);
+    manager->ctx = g_udev_client_new(subsys);
 
-    g_signal_connect(priv->ctx, "uevent", G_CALLBACK(do_udev_event), manager);
+    g_signal_connect(manager->ctx, "uevent", G_CALLBACK(do_udev_event),
+                     manager);
 
-    devs = g_udev_client_query_by_subsystem(priv->ctx, "usb");
+    devs = g_udev_client_query_by_subsystem(manager->ctx, "usb");
 
     tmp = devs;
     while (tmp) {
         GUdevDevice *dev = tmp->data;
 
-        do_udev_event(priv->ctx, "add", dev, manager);
+        do_udev_event(manager->ctx, "add", dev, manager);
 
         g_object_unref(dev);
         tmp = tmp->next;
@@ -160,23 +154,20 @@ static void entangle_device_manager_init_devices(EntangleDeviceManager *manager)
     g_list_free(devs);
 }
 
-
-static void entangle_device_manager_init(EntangleDeviceManager *manager)
+static void
+entangle_device_manager_init(EntangleDeviceManager *manager)
 {
-    manager->priv = ENTANGLE_DEVICE_MANAGER_GET_PRIVATE(manager);
-
     entangle_device_manager_init_devices(manager);
 }
 
-
-char *entangle_device_manager_serial_id(EntangleDeviceManager *manager,
-                                        const char *devpath)
+char *
+entangle_device_manager_serial_id(EntangleDeviceManager *manager,
+                                  const char *devpath)
 {
-    EntangleDeviceManagerPrivate *priv = manager->priv;
     GUdevDevice *dev;
     char *ret;
 
-    dev = g_udev_client_query_by_device_file(priv->ctx, devpath);
+    dev = g_udev_client_query_by_device_file(manager->ctx, devpath);
 
     if (!dev)
         return NULL;
