@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,23 +23,26 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gexiv2/gexiv2.h>
+
 #include "entangle-image.h"
 
 G_BEGIN_DECLS
 
-GdkPixbuf *entangle_pixbuf_auto_rotate(GdkPixbuf *src,
-                                       GExiv2Metadata *metadata);
+GdkPixbuf *
+entangle_pixbuf_auto_rotate(GdkPixbuf *src, GExiv2Metadata *metadata);
 
-typedef enum {
-  ENTANGLE_PIXBUF_IMAGE_SLOT_MASTER,
-  ENTANGLE_PIXBUF_IMAGE_SLOT_PREVIEW,
-  ENTANGLE_PIXBUF_IMAGE_SLOT_THUMBNAIL,
+typedef enum
+{
+    ENTANGLE_PIXBUF_IMAGE_SLOT_MASTER,
+    ENTANGLE_PIXBUF_IMAGE_SLOT_PREVIEW,
+    ENTANGLE_PIXBUF_IMAGE_SLOT_THUMBNAIL,
 } EntanglePixbufImageSlot;
 
-GdkPixbuf *entangle_pixbuf_open_image(EntangleImage *image,
-                                      EntanglePixbufImageSlot slot,
-                                      gboolean applyOrientation,
-                                      GExiv2Metadata **metadata);
+GdkPixbuf *
+entangle_pixbuf_open_image(EntangleImage *image,
+                           EntanglePixbufImageSlot slot,
+                           gboolean applyOrientation,
+                           GExiv2Metadata **metadata);
 
 #endif /* __ENTANGLE_PIXBUF_H__ */
 
