@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,28 +18,41 @@
  *
  */
 
-#include "entangle-debug.h"
 #include "entangle-progress.h"
 
-void entangle_progress_start(EntangleProgress *prog, float target, const char *msg)
+#include "entangle-debug.h"
+
+/**
+ * SECTION:entangle-progress
+ * @Short_description: an interface for monitoring operation progress
+ * @Title: EntangleProgress
+ *
+ * The #EntangleProgress interface provides a way to monitor the progress
+ * of operations performed by the camera.
+ */
+
+void
+entangle_progress_start(EntangleProgress *prog, float target, const char *msg)
 {
     g_return_if_fail(ENTANGLE_IS_PROGRESS(prog));
 
-    ENTANGLE_PROGRESS_GET_INTERFACE(prog)->start(prog, target, msg);
+    ENTANGLE_PROGRESS_GET_IFACE(prog)->start(prog, target, msg);
 }
 
-void entangle_progress_update(EntangleProgress *prog, float current)
+void
+entangle_progress_update(EntangleProgress *prog, float current)
 {
     g_return_if_fail(ENTANGLE_IS_PROGRESS(prog));
 
-    ENTANGLE_PROGRESS_GET_INTERFACE(prog)->update(prog, current);
+    ENTANGLE_PROGRESS_GET_IFACE(prog)->update(prog, current);
 }
 
-void entangle_progress_stop(EntangleProgress *prog)
+void
+entangle_progress_stop(EntangleProgress *prog)
 {
     g_return_if_fail(ENTANGLE_IS_PROGRESS(prog));
 
-    ENTANGLE_PROGRESS_GET_INTERFACE(prog)->stop(prog);
+    ENTANGLE_PROGRESS_GET_IFACE(prog)->stop(prog);
 }
 
 GType
@@ -48,10 +61,9 @@ entangle_progress_get_type(void)
     static GType progress_type = 0;
 
     if (!progress_type) {
-        progress_type =
-            g_type_register_static_simple(G_TYPE_INTERFACE, "EntangleProgress",
-                                          sizeof(EntangleProgressInterface),
-                                          NULL, 0, NULL, 0);
+        progress_type = g_type_register_static_simple(
+            G_TYPE_INTERFACE, "EntangleProgress",
+            sizeof(EntangleProgressInterface), NULL, 0, NULL, 0);
 
         g_type_interface_add_prerequisite(progress_type, G_TYPE_OBJECT);
     }
