@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,27 +27,30 @@
 
 G_BEGIN_DECLS
 
-#define ENTANGLE_TYPE_PROGRESS                (entangle_progress_get_type ())
-#define ENTANGLE_PROGRESS(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), ENTANGLE_TYPE_PROGRESS, EntangleProgress))
-#define ENTANGLE_IS_PROGRESS(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ENTANGLE_TYPE_PROGRESS))
-#define ENTANGLE_PROGRESS_GET_INTERFACE(inst) (G_TYPE_INSTANCE_GET_INTERFACE ((inst), ENTANGLE_TYPE_PROGRESS, EntangleProgressInterface))
+#define ENTANGLE_TYPE_PROGRESS (entangle_progress_get_type())
+G_DECLARE_INTERFACE(EntangleProgress,
+                    entangle_progress,
+                    ENTANGLE,
+                    PROGRESS,
+                    GObject)
 
-typedef struct _EntangleProgress EntangleProgress; /* dummy object */
-typedef struct _EntangleProgressInterface EntangleProgressInterface;
-
-struct _EntangleProgressInterface {
+struct _EntangleProgressInterface
+{
+    /*< private >*/
     GTypeInterface parent;
 
-    void (*start) (EntangleProgress *prog, float target, const char *msg);
-    void (*update) (EntangleProgress *prog, float current);
-    void (*stop) (EntangleProgress *prog);
+    /*< public >*/
+    void (*start)(EntangleProgress *prog, float target, const char *msg);
+    void (*update)(EntangleProgress *prog, float current);
+    void (*stop)(EntangleProgress *prog);
 };
 
-GType entangle_progress_get_type(void);
-
-void entangle_progress_start(EntangleProgress *prog, float target, const char *msg);
-void entangle_progress_update(EntangleProgress *prog, float current);
-void entangle_progress_stop(EntangleProgress *prog);
+void
+entangle_progress_start(EntangleProgress *prog, float target, const char *msg);
+void
+entangle_progress_update(EntangleProgress *prog, float current);
+void
+entangle_progress_stop(EntangleProgress *prog);
 
 G_END_DECLS
 
