@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,23 +18,33 @@
  *
  */
 
-#include <glib.h>
-#include <gio/gio.h>
+#include <errno.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <errno.h>
-#include <stdlib.h>
+
+#include <gio/gio.h>
+#include <glib.h>
+
+#include "entangle-session.h"
 
 #include "entangle-debug.h"
-#include "entangle-session.h"
 #include "entangle-image.h"
 #include "entangle-video.h"
 
-#define ENTANGLE_SESSION_GET_PRIVATE(obj)                                   \
-    (G_TYPE_INSTANCE_GET_PRIVATE((obj), ENTANGLE_TYPE_SESSION, EntangleSessionPrivate))
+/**
+ * SECTION:entangle-session
+ * @Short_description: a collection of media files
+ * @Title: EntangleSession
+ *
+ * The #EntangleSession object represents a collection of media files
+ * used during the current capture session.
+ */
 
-struct _EntangleSessionPrivate {
+struct _EntangleSession
+{
+    GObject parent;
     char *directory;
     char *filenamePattern;
     gboolean recalculateDigit;
@@ -46,29 +56,30 @@ struct _EntangleSessionPrivate {
     GList *files;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE(EntangleSession, entangle_session, G_TYPE_OBJECT);
+G_DEFINE_TYPE(EntangleSession, entangle_session, G_TYPE_OBJECT);
 
-enum {
+enum
+{
     PROP_0,
     PROP_DIRECTORY,
     PROP_FILENAME_PATTERN,
 };
 
-static void entangle_session_get_property(GObject *object,
-                                          guint prop_id,
-                                          GValue *value,
-                                          GParamSpec *pspec)
+static void
+entangle_session_get_property(GObject *object,
+                              guint prop_id,
+                              GValue *value,
+                              GParamSpec *pspec)
 {
-    EntangleSession *picker = ENTANGLE_SESSION(object);
-    EntangleSessionPrivate *priv = picker->priv;
+    EntangleSession *session = ENTANGLE_SESSION(object);
 
     switch (prop_id) {
     case PROP_DIRECTORY:
-        g_value_set_string(value, priv->directory);
+        g_value_set_string(value, session->directory);
         break;
 
     case PROP_FILENAME_PATTERN:
-        g_value_set_string(value, priv->filenamePattern);
+        g_value_set_string(value, session->filenamePattern);
         break;
 
     default:
@@ -76,25 +87,40 @@ static void entangle_session_get_property(GObject *object,
     }
 }
 
-static void entangle_session_set_property(GObject *object,
-                                          guint prop_id,
-                                          const GValue *value,
-                                          GParamSpec *pspec)
+static char *
+entangle_session_sanitize_pattern(const char *pattern)
 {
-    EntangleSession *picker = ENTANGLE_SESSION(object);
-    EntangleSessionPrivate *priv = picker->priv;
+    if (!pattern) {
+        ENTANGLE_DEBUG("Filename pattern is NULL");
+        pattern = "captureXXXXXX";
+    } else if (!strstr(pattern, "XXXXXX")) {
+        ENTANGLE_DEBUG("Filename pattern '%s' lacks placeholders", pattern);
+        pattern = "captureXXXXXX";
+    }
+
+    return g_strdup(pattern);
+}
+
+static void
+entangle_session_set_property(GObject *object,
+                              guint prop_id,
+                              const GValue *value,
+                              GParamSpec *pspec)
+{
+    EntangleSession *session = ENTANGLE_SESSION(object);
 
     switch (prop_id) {
     case PROP_DIRECTORY:
-        g_free(priv->directory);
-        priv->directory = g_value_dup_string(value);
-        g_mkdir_with_parents(priv->directory, 0777);
+        g_free(session->directory);
+        session->directory = g_value_dup_string(value);
+        g_mkdir_with_parents(session->directory, 0777);
         break;
 
     case PROP_FILENAME_PATTERN:
-        g_free(priv->filenamePattern);
-        priv->filenamePattern = g_value_dup_string(value);
-        priv->recalculateDigit = TRUE;
+        g_free(session->filenamePattern);
+        session->filenamePattern =
+            entangle_session_sanitize_pattern(g_value_get_string(value));
+        session->recalculateDigit = TRUE;
         break;
 
     default:
@@ -102,37 +128,36 @@ static void entangle_session_set_property(GObject *object,
     }
 }
 
-
-static void do_media_unref(gpointer object,
-                           gpointer opaque G_GNUC_UNUSED)
+static void
+do_media_unref(gpointer object, gpointer opaque G_GNUC_UNUSED)
 {
     EntangleMedia *media = object;
 
     g_object_unref(media);
 }
 
-static void entangle_session_finalize(GObject *object)
+static void
+entangle_session_finalize(GObject *object)
 {
     EntangleSession *session = ENTANGLE_SESSION(object);
-    EntangleSessionPrivate *priv = session->priv;
 
     ENTANGLE_DEBUG("Finalize session %p", object);
 
-    if (priv->files) {
-        g_list_foreach(priv->files, do_media_unref, NULL);
-        g_list_free(priv->files);
+    if (session->files) {
+        g_list_foreach(session->files, do_media_unref, NULL);
+        g_list_free(session->files);
     }
 
-    g_free(priv->lastFilePrefixSrc);
-    g_free(priv->lastFilePrefixDst);
-    g_free(priv->filenamePattern);
-    g_free(priv->directory);
+    g_free(session->lastFilePrefixSrc);
+    g_free(session->lastFilePrefixDst);
+    g_free(session->filenamePattern);
+    g_free(session->directory);
 
     G_OBJECT_CLASS(entangle_session_parent_class)->finalize(object);
 }
 
-
-static void entangle_session_class_init(EntangleSessionClass *klass)
+static void
+entangle_session_class_init(EntangleSessionClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
@@ -140,50 +165,32 @@ static void entangle_session_class_init(EntangleSessionClass *klass)
     object_class->get_property = entangle_session_get_property;
     object_class->set_property = entangle_session_set_property;
 
-    g_signal_new("session-media-added",
-                 G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_FIRST,
-                 0, NULL, NULL,
-                 g_cclosure_marshal_VOID__OBJECT,
-                 G_TYPE_NONE,
-                 1,
+    g_signal_new("session-media-added", G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
                  ENTANGLE_TYPE_MEDIA);
 
-    g_signal_new("session-media-removed",
-                 G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_FIRST,
-                 0, NULL, NULL,
-                 g_cclosure_marshal_VOID__OBJECT,
-                 G_TYPE_NONE,
-                 1,
+    g_signal_new("session-media-removed", G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
                  ENTANGLE_TYPE_MEDIA);
 
-    g_object_class_install_property(object_class,
-                                    PROP_DIRECTORY,
-                                    g_param_spec_string("directory",
-                                                        "Session directory",
-                                                        "Full path to session file",
-                                                        NULL,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY |
-                                                        G_PARAM_STATIC_NAME |
-                                                        G_PARAM_STATIC_NICK |
-                                                        G_PARAM_STATIC_BLURB));
+    g_object_class_install_property(
+        object_class, PROP_DIRECTORY,
+        g_param_spec_string(
+            "directory", "Session directory", "Full path to session file", NULL,
+            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME |
+                G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-    g_object_class_install_property(object_class,
-                                    PROP_FILENAME_PATTERN,
-                                    g_param_spec_string("filename-pattern",
-                                                        "Filename patern",
-                                                        "Pattern for creating new filenames",
-                                                        NULL,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY |
-                                                        G_PARAM_STATIC_NAME |
-                                                        G_PARAM_STATIC_NICK |
-                                                        G_PARAM_STATIC_BLURB));
+    g_object_class_install_property(
+        object_class, PROP_FILENAME_PATTERN,
+        g_param_spec_string("filename-pattern", "Filename patern",
+                            "Pattern for creating new filenames", NULL,
+                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+                                G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |
+                                G_PARAM_STATIC_BLURB));
 }
 
-
 /**
  * entangle_session_new:
  * @directory: the directory associated witht session
@@ -195,26 +202,20 @@ static void entangle_session_class_init(EntangleSessionClass *klass)
  *
  * Returns: (transfer full): the new session
  */
-EntangleSession *entangle_session_new(const char *directory,
-                                      const char *filenamePattern)
+EntangleSession *
+entangle_session_new(const char *directory, const char *filenamePattern)
 {
-    return ENTANGLE_SESSION(g_object_new(ENTANGLE_TYPE_SESSION,
-                                         "directory", directory,
-                                         "filename-pattern", filenamePattern,
-                                         NULL));
+    return ENTANGLE_SESSION(g_object_new(ENTANGLE_TYPE_SESSION, "directory",
+                                         directory, "filename-pattern",
+                                         filenamePattern, NULL));
 }
 
-
-static void entangle_session_init(EntangleSession *session)
+static void
+entangle_session_init(EntangleSession *session)
 {
-    EntangleSessionPrivate *priv;
-
-    priv = session->priv = ENTANGLE_SESSION_GET_PRIVATE(session);
-
-    priv->recalculateDigit = TRUE;
+    session->recalculateDigit = TRUE;
 }
 
-
 /**
  * entangle_session_directory:
  * @session: (transfer none): the session instance
@@ -223,16 +224,14 @@ static void entangle_session_init(EntangleSession *session)
  *
  * Returns: (transfer none): the session directory
  */
-const char *entangle_session_directory(EntangleSession *session)
+const char *
+entangle_session_directory(EntangleSession *session)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), NULL);
 
-    EntangleSessionPrivate *priv = session->priv;
-
-    return priv->directory;
+    return session->directory;
 }
 
-
 /**
  * entangle_session_filename_pattern:
  * @session: (transfer none): the session instance
@@ -241,23 +240,22 @@ const char *entangle_session_directory(EntangleSession *session)
  *
  * Returns: (transfer none): the filename pattern
  */
-const char *entangle_session_filename_pattern(EntangleSession *session)
+const char *
+entangle_session_filename_pattern(EntangleSession *session)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), NULL);
 
-    EntangleSessionPrivate *priv = session->priv;
-
-    return priv->filenamePattern;
+    return session->filenamePattern;
 }
 
-
-static gint entangle_session_next_digit(EntangleSession *session)
+static gint
+entangle_session_next_digit(EntangleSession *session)
 {
-    EntangleSessionPrivate *priv = session->priv;
     gint maxDigit = -1;
-    GList *files = priv->files;
-    const gchar *template = strchr(priv->filenamePattern, 'X');
-    gchar *prefix = g_strndup(priv->filenamePattern, (template - priv->filenamePattern));
+    GList *files = session->files;
+    const gchar *template = strchr(session->filenamePattern, 'X');
+    gchar *prefix = g_strndup(session->filenamePattern,
+                              (template - session->filenamePattern));
     gint prefixlen = strlen(prefix);
     gsize templatelen = 0;
     const gchar *postfix;
@@ -265,14 +263,15 @@ static gint entangle_session_next_digit(EntangleSession *session)
 
     while (*template == 'X') {
         templatelen++;
-        template++;
+        template ++;
     }
 
     postfix = template;
     postfixlen = strlen(postfix);
 
-    ENTANGLE_DEBUG("Template '%s' with prefixlen %d, %zu digits and postfix %zu",
-                   priv->filenamePattern, prefixlen, templatelen, postfixlen);
+    ENTANGLE_DEBUG(
+        "Template '%s' with prefixlen %d, %zu digits and postfix %zu",
+        session->filenamePattern, prefixlen, templatelen, postfixlen);
 
     while (files) {
         EntangleMedia *media = files->data;
@@ -280,19 +279,20 @@ static gint entangle_session_next_digit(EntangleSession *session)
         gsize used = 0;
         gint digit = 0;
 
-        if (!g_str_has_prefix(name, priv->directory)) {
-            ENTANGLE_DEBUG("File %s does not match directory",
-                           entangle_media_get_filename(media));
+        if (!g_str_has_prefix(name, session->directory)) {
+            ENTANGLE_DEBUG("File %s does not match directory %s",
+                           entangle_media_get_filename(media),
+                           session->directory);
             goto next;
         }
-        name += strlen(priv->directory);
+        name += strlen(session->directory);
         while (*name == '/')
             name++;
 
         /* Ignore files not matching the template prefix */
         if (!g_str_has_prefix(name, prefix)) {
-            ENTANGLE_DEBUG("File %s does not match prefix",
-                           entangle_media_get_filename(media));
+            ENTANGLE_DEBUG("File %s does not match prefix %s",
+                           entangle_media_get_filename(media), prefix);
             goto next;
         }
 
@@ -342,11 +342,10 @@ static gint entangle_session_next_digit(EntangleSession *session)
     return maxDigit + 1;
 }
 
-
-static char *entangle_session_next_file_prefix(EntangleSession *session)
+static char *
+entangle_session_next_file_prefix(EntangleSession *session)
 {
-    EntangleSessionPrivate *priv = session->priv;
-    const char *template = strchr(priv->filenamePattern, 'X');
+    const char *template = strchr(session->filenamePattern, 'X');
     const char *postfix;
     char *prefix;
     char *format;
@@ -358,31 +357,30 @@ static char *entangle_session_next_file_prefix(EntangleSession *session)
     if (!template)
         return NULL;
 
-    if (priv->recalculateDigit) {
-        priv->nextFilenameDigit = entangle_session_next_digit(session);
-        priv->recalculateDigit = FALSE;
+    if (session->recalculateDigit) {
+        session->nextFilenameDigit = entangle_session_next_digit(session);
+        session->recalculateDigit = FALSE;
     }
 
     postfix = template;
     while (*postfix == 'X')
         postfix++;
 
-    prefix = g_strndup(priv->filenamePattern,
-                       template - priv->filenamePattern);
+    prefix = g_strndup(session->filenamePattern,
+                       template - session->filenamePattern);
 
     ndigits = postfix - template;
 
     format = g_strdup_printf("%%s%%0%dd%%s", ndigits);
 
-    ENTANGLE_DEBUG("Format '%s' prefix='%s' postfix='%s' ndigits=%d nextDigits=%d",
-                   format, prefix, postfix, ndigits, priv->nextFilenameDigit);
+    ENTANGLE_DEBUG(
+        "Format '%s' prefix='%s' postfix='%s' ndigits=%d nextDigits=%d", format,
+        prefix, postfix, ndigits, session->nextFilenameDigit);
 
-    filename = g_strdup_printf(format,
-                               prefix,
-                               priv->nextFilenameDigit,
-                               postfix);
+    filename =
+        g_strdup_printf(format, prefix, session->nextFilenameDigit, postfix);
 
-    priv->nextFilenameDigit++;
+    session->nextFilenameDigit++;
 
     g_free(prefix);
     g_free(format);
@@ -390,7 +388,6 @@ static char *entangle_session_next_file_prefix(EntangleSession *session)
     return filename;
 }
 
-
 /**
  * entangle_session_next_filename:
  * @session: (transfer none): the session instance
@@ -402,21 +399,21 @@ static char *entangle_session_next_file_prefix(EntangleSession *session)
  *
  * Returns: (transfer full): the new filename
  */
-char *entangle_session_next_filename(EntangleSession *session,
-                                     EntangleCameraFile *file)
+char *
+entangle_session_next_filename(EntangleSession *session,
+                               EntangleCameraFile *file)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), NULL);
 
-    EntangleSessionPrivate *priv = session->priv;
     const char *srcname = entangle_camera_file_get_name(file);
     char *dstname = NULL;
     char *ext = NULL;
     char *srcprefix = NULL;
 
-    ENTANGLE_DEBUG("Next filename %s against (%s, %s)",
-                   srcname,
-                   priv->lastFilePrefixSrc ? priv->lastFilePrefixSrc : "",
-                   priv->lastFilePrefixDst ? priv->lastFilePrefixDst : "");
+    ENTANGLE_DEBUG("Next filename %s against (%s, %s)", srcname,
+                   session->lastFilePrefixSrc ? session->lastFilePrefixSrc : "",
+                   session->lastFilePrefixDst ? session->lastFilePrefixDst
+                                              : "");
 
     if (srcname) {
         const char *offset = strrchr(srcname, '.');
@@ -428,22 +425,19 @@ char *entangle_session_next_filename(EntangleSession *session,
         }
     }
 
-    if (srcprefix &&
-        priv->lastFilePrefixSrc &&
-        priv->lastFilePrefixDst &&
-        g_str_equal(priv->lastFilePrefixSrc, srcprefix)) {
+    if (srcprefix && session->lastFilePrefixSrc && session->lastFilePrefixDst &&
+        g_str_equal(session->lastFilePrefixSrc, srcprefix)) {
     } else {
-        g_free(priv->lastFilePrefixSrc);
-        g_free(priv->lastFilePrefixDst);
-        priv->lastFilePrefixSrc = srcprefix;
-        priv->lastFilePrefixDst = entangle_session_next_file_prefix(session);
+        g_free(session->lastFilePrefixSrc);
+        g_free(session->lastFilePrefixDst);
+        session->lastFilePrefixSrc = srcprefix;
+        session->lastFilePrefixDst = entangle_session_next_file_prefix(session);
     }
 
-    if (priv->lastFilePrefixDst)
-        dstname = g_strdup_printf("%s/%s.%s",
-                                  priv->directory,
-                                  priv->lastFilePrefixDst,
-                                  ext ? ext : "jpeg");
+    if (session->lastFilePrefixDst)
+        dstname =
+            g_strdup_printf("%s/%s.%s", session->directory,
+                            session->lastFilePrefixDst, ext ? ext : "jpeg");
     g_free(ext);
 
     ENTANGLE_DEBUG("Built '%s'", dstname);
@@ -457,15 +451,14 @@ char *entangle_session_next_filename(EntangleSession *session,
     return dstname;
 }
 
-
-static gint entangle_session_compare_media(gconstpointer a,
-                                           gconstpointer b)
+static gint
+entangle_session_compare_media(gconstpointer a, gconstpointer b)
 {
     EntangleMedia *mediaa = (EntangleMedia *)a;
     EntangleMedia *mediab = (EntangleMedia *)b;
 
     return entangle_media_get_last_modified(mediaa) -
-        entangle_media_get_last_modified(mediab);
+           entangle_media_get_last_modified(mediab);
 }
 
 /**
@@ -475,23 +468,20 @@ static gint entangle_session_compare_media(gconstpointer a,
  *
  * Add @media to the @session
  */
-void entangle_session_add_media(EntangleSession *session, EntangleMedia *media)
+void
+entangle_session_add_media(EntangleSession *session, EntangleMedia *media)
 {
     g_return_if_fail(ENTANGLE_IS_SESSION(session));
     g_return_if_fail(ENTANGLE_IS_MEDIA(media));
 
-    EntangleSessionPrivate *priv = session->priv;
-
     g_object_ref(media);
 
-    priv->files = g_list_insert_sorted(priv->files,
-                                        media,
-                                        entangle_session_compare_media);
+    session->files = g_list_insert_sorted(session->files, media,
+                                          entangle_session_compare_media);
 
     g_signal_emit_by_name(session, "session-media-added", media);
 }
 
-
 /**
  * entangle_session_remove_media:
  * @session: (transfer none): the session instance
@@ -499,24 +489,23 @@ void entangle_session_add_media(EntangleSession *session, EntangleMedia *media)
  *
  * Remove @media from the @session
  */
-void entangle_session_remove_media(EntangleSession *session, EntangleMedia *media)
+void
+entangle_session_remove_media(EntangleSession *session, EntangleMedia *media)
 {
     g_return_if_fail(ENTANGLE_IS_SESSION(session));
     g_return_if_fail(ENTANGLE_IS_MEDIA(media));
 
-    EntangleSessionPrivate *priv = session->priv;
-    GList *tmp = g_list_find(priv->files, media);
+    GList *tmp = g_list_find(session->files, media);
 
     if (!tmp)
         return;
 
-    priv->files = g_list_delete_link(priv->files, tmp);
+    session->files = g_list_delete_link(session->files, tmp);
 
     g_signal_emit_by_name(session, "session-media-removed", media);
     g_object_unref(media);
 }
 
-
 /**
  * entangle_session_load:
  * @session: (transfer none): the session instance
@@ -526,20 +515,19 @@ void entangle_session_remove_media(EntangleSession *session, EntangleMedia *medi
  *
  * Returns: TRUE if the session was loaded
  */
-gboolean entangle_session_load(EntangleSession *session)
+gboolean
+entangle_session_load(EntangleSession *session)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), FALSE);
 
-    EntangleSessionPrivate *priv = session->priv;
-    GFile *dir = g_file_new_for_path(priv->directory);
+    GFile *dir = g_file_new_for_path(session->directory);
     GList *tmp;
-    GFileEnumerator *children = g_file_enumerate_children(dir,
-                                                          "standard::name,standard::type",
-                                                          G_FILE_QUERY_INFO_NONE,
-                                                          NULL,
-                                                          NULL);
+    GFileEnumerator *children =
+        g_file_enumerate_children(dir, "standard::name,standard::type",
+                                  G_FILE_QUERY_INFO_NONE, NULL, NULL);
     GFileInfo *childinfo;
-    while ((childinfo = g_file_enumerator_next_file(children, NULL, NULL)) != NULL) {
+    while ((childinfo = g_file_enumerator_next_file(children, NULL, NULL)) !=
+           NULL) {
         const gchar *thisname = g_file_info_get_name(childinfo);
         GFile *child = g_file_get_child(dir, thisname);
         if (g_file_info_get_file_type(childinfo) == G_FILE_TYPE_REGULAR ||
@@ -549,8 +537,7 @@ gboolean entangle_session_load(EntangleSession *session)
             EntangleMedia *media = NULL;
             char *filename = g_file_get_path(child);
 
-            if (!(ctype = g_content_type_guess(filename,
-                                               NULL, 0, NULL))) {
+            if (!(ctype = g_content_type_guess(filename, NULL, 0, NULL))) {
                 ENTANGLE_DEBUG("No content type for %s", filename);
                 g_free(filename);
                 continue;
@@ -570,13 +557,13 @@ gboolean entangle_session_load(EntangleSession *session)
             } else if (g_str_has_prefix(mimetype, "video/")) {
                 media = ENTANGLE_MEDIA(entangle_video_new_file(filename));
             } else {
-                ENTANGLE_DEBUG("Mime type %s for file %s not wanted",
-                               mimetype, filename);
+                ENTANGLE_DEBUG("Mime type %s for file %s not wanted", mimetype,
+                               filename);
             }
             g_free(mimetype);
             if (media) {
                 ENTANGLE_DEBUG("Adding '%s'", filename);
-                priv->files = g_list_prepend(priv->files, media);
+                session->files = g_list_prepend(session->files, media);
             }
             g_free(filename);
         }
@@ -586,24 +573,23 @@ gboolean entangle_session_load(EntangleSession *session)
 
     g_object_unref(children);
 
-    priv->files = g_list_sort(priv->files,
-                               entangle_session_compare_media);
+    session->files =
+        g_list_sort(session->files, entangle_session_compare_media);
 
-    tmp = priv->files;
+    tmp = session->files;
     while (tmp) {
         EntangleMedia *media = ENTANGLE_MEDIA(tmp->data);
         g_signal_emit_by_name(session, "session-media-added", media);
         tmp = tmp->next;
     }
 
-    priv->recalculateDigit = TRUE;
+    session->recalculateDigit = TRUE;
 
     g_object_unref(dir);
 
     return TRUE;
 }
 
-
 /**
  * entangle_session_get_media_count:
  * @session: (transfer none): the session instance
@@ -612,16 +598,14 @@ gboolean entangle_session_load(EntangleSession *session)
  *
  * Returns: the file count
  */
-int entangle_session_get_media_count(EntangleSession *session)
+int
+entangle_session_get_media_count(EntangleSession *session)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), 0);
 
-    EntangleSessionPrivate *priv = session->priv;
-
-    return g_list_length(priv->files);
+    return g_list_length(session->files);
 }
 
-
 /**
  * entangle_session_get_media:
  * @session: (transfer none): the session instance
@@ -631,13 +615,12 @@ int entangle_session_get_media_count(EntangleSession *session)
  *
  * Returns: (transfer none): the media file
  */
-EntangleMedia *entangle_session_get_media(EntangleSession *session, int idx)
+EntangleMedia *
+entangle_session_get_media(EntangleSession *session, int idx)
 {
     g_return_val_if_fail(ENTANGLE_IS_SESSION(session), NULL);
 
-    EntangleSessionPrivate *priv = session->priv;
-
-    return g_list_nth_data(priv->files, idx);
+    return g_list_nth_data(session->files, idx);
 }
 
 /*
