@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2018 Daniel P. Berrange
+ *  Copyright (C) 2009-2018 Daniel P. Berrangé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
 
 #include <glib.h>
 
-gboolean entangle_dpms_set_blanking(gboolean enabled,
-                                    GError **error);
+gboolean
+entangle_dpms_set_blanking(gboolean enabled, GError **error);
 
 #endif /* __ENTANGLE_DPMS_H__ */
 
