@@ -1,7 +1,7 @@
 #
 # Entangle: Tethered Camera Control & Capture
 #
-# Copyright (C) 2014-2017 Daniel P. Berrange
+# Copyright (C) 2014-2017 Daniel P. Berrangé
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -109,52 +109,81 @@ class PhotoBoxPluginWindow(object):
         self.config = config
         self.win = win
         self.action = None
-        self.button = Gtk.Button("Shoot")
+        self.shoot = Gtk.Button("Shoot")
+        self.shoot.set_border_width(6)
+        self.delay = Gtk.Scale.new_with_range(0, 0, 10, 1)
+        self.delay.set_value(5)
+        self.delay.set_hexpand(True)
+        self.delay.set_value_pos(Gtk.PositionType.RIGHT)
+        self.settings = Gtk.Grid()
+        self.settings.attach(Gtk.Label("Countdown time:"), 0, 0, 1, 1)
+        self.settings.attach(self.delay, 1, 0, 1, 1)
+        self.settings.attach(Gtk.Label("secs"), 2, 0, 1, 1)
+        self.settings.set_column_spacing(3)
+        self.settings.set_border_width(6)
         self.winsig = None
-        self.buttonsig = None
+        self.shootsig = None
 
     def do_set_widget_state(self, visible):
         settings = self.win.get_template_child(Entangle.CameraManager, "settingsScroll")
         settings.set_visible(visible)
 
+    def do_clear_greeting(self):
+        self.imageDisplay.set_text_overlay(None)
+        self.greetingSig = 0
+
     def do_start_photobox(self):
         self.do_set_widget_state(False)
         pane = self.win.get_template_child(Entangle.CameraManager, "winBox")
-        pane.pack_start(self.button, False, True, 0)
-        self.button.show()
-        self.button.grab_focus()
+        pane.pack_start(self.settings, False, True, 0)
+        self.settings.show_all()
+        pane.pack_start(self.shoot, False, True, 0)
+        self.shoot.show()
+        self.shoot.grab_focus()
         self.win.fullscreen()
         self.winsig = self.win.connect("key-release-event", self.do_key_release)
-        self.buttonsig = self.button.connect("clicked", self.do_capture)
+        self.shootsig = self.shoot.connect("clicked", self.do_capture)
+
+        panel = self.win.get_template_child(Entangle.CameraManager, "displayPanel")
+        overlay = panel.get_child1()
+        scroll = overlay.get_child()
+        viewport = scroll.get_child()
+        self.imageDisplay = viewport.get_child()
+        self.camera = self.win.get_camera()
+
+        app = self.win.get_application()
+        prefs = app.get_preferences()
+        self.continuousPreview = prefs.capture_get_continuous_preview()
+        prefs.capture_set_continuous_preview(False)
+
+        self.win.set_media_context_menu(False)
+
+        self.imageDisplay.set_text_overlay("Press 'Escape' to exit photo box")
+        self.greetingSig = GLib.timeout_add(3000, self.do_clear_greeting)
 
     def do_stop_photobox(self):
         self.do_set_widget_state(True)
         pane = self.win.get_template_child(Entangle.CameraManager, "winBox")
-        pane.remove(self.button)
+        pane.remove(self.shoot)
+        pane.remove(self.settings)
         self.win.unfullscreen()
         self.win.disconnect(self.winsig)
-        self.button.disconnect(self.buttonsig)
+        self.shoot.disconnect(self.shootsig)
+        self.imageDisplay.set_text_overlay(None)
 
-    def do_close_greeting(self, src, response, data=None):
-        src.set_visible(False)
-        src.destroy()
+        if self.greetingSig != 0:
+            GLib.source_remove(self.greetingSig)
+            self.greetingSig = 0
 
-    def do_show_greeting(self):
-        dlg = Gtk.MessageDialog(title="Photo box active",
-                                parent=self.win,
-                                flags=Gtk.DialogFlags.MODAL,
-                                type=Gtk.MessageType.INFO,
-                                buttons=Gtk.ButtonsType.OK)
-        dlg.set_markup("Press 'Escape' to exit photo box")
-        dlg.set_transient_for(self.win)
-        dlg.connect("response", self.do_close_greeting)
-        dlg.show()
+        app = self.win.get_application()
+        prefs = app.get_preferences()
+        prefs.capture_set_continuous_preview(self.continuousPreview)
+
+        self.win.set_media_context_menu(True)
 
     def do_toggle_photobox(self, action, state, data=None):
         if state.unpack():
             self.do_start_photobox()
-
-            GLib.timeout_add(500, self.do_show_greeting)
         else:
             self.do_stop_photobox()
 
@@ -170,8 +199,35 @@ class PhotoBoxPluginWindow(object):
                     self.action.change_state(GLib.Variant('b', False))
                 dlg.destroy()
 
+    def displaycounter(self):
+        if self.timer > 0:
+            t = str(self.timer)
+            self.imageDisplay.set_text_overlay(t)
+            self.timer = self.timer - 1
+            return True
+        else:
+            self.imageDisplay.set_text_overlay(None)
+            self.win.capture()
+            return False
+
+    def do_countdown_start(self, src, camfile):
+        if self.greetingSig != 0:
+            GLib.source_remove(self.greetingSig)
+            self.greetingSig = 0
+
+        self.displaycounter()
+        GLib.timeout_add(1000, self.displaycounter)
+        self.camera.disconnect(self.previewSig)
+        return False
+
     def do_capture(self, src):
-        self.win.capture()
+        self.timer = int(self.delay.get_value())
+        if self.timer > 0:
+            self.previewSig = self.camera.connect("camera-file-previewed",
+                                                  self.do_countdown_start)
+            self.win.preview_begin()
+        else:
+            self.win.capture()
 
     def do_state_photobox(self, action, data=None):
         action.change_state(GLib.Variant('b', not action.get_state()))
